pub struct AgglayerConfig {
pub bridge_admin: AccountFile,
pub ger_manager: AccountFile,
pub bridge: AccountFile,
pub faucet: AccountFile,
}Expand description
Configuration for agglayer tests when running against a node with pre-deployed agglayer accounts (e.g. complete genesis or devnet).
Loaded from .mac files in the directory specified by AGGLAYER_ACCOUNTS_DIR env var.
Account IDs and keys are read from files, but the actual account state is fetched
from the network to ensure it’s up-to-date (idempotent across repeated runs).
Fields
bridge_admin: AccountFileger_manager: AccountFilebridge: AccountFilefaucet: AccountFileImplementations
Sourceimpl AgglayerConfig
impl AgglayerConfig
Sourcepub fn from_env() -> Result<Option<Self>>
pub fn from_env() -> Result<Option<Self>>
Tries to load agglayer config from the AGGLAYER_ACCOUNTS_DIR env var.
Returns None if the env var is not set.
pub fn bridge_admin_id(&self) -> AccountId
pub fn ger_manager_id(&self) -> AccountId
pub fn bridge_id(&self) -> AccountId
pub fn faucet_id(&self) -> AccountId
Sourcepub async fn import_account(
&self,
account_id: AccountId,
client: &mut TestClient,
keystore: &FilesystemKeyStore,
) -> Result<()>
pub async fn import_account( &self, account_id: AccountId, client: &mut TestClient, keystore: &FilesystemKeyStore, ) -> Result<()>
Imports a single account (by ID) into the given client and keystore. Fetches the latest state from the network. Adds any matching secret keys.