pub struct ClientConfig {
pub rpc_endpoint: Endpoint,
pub rpc_timeout_ms: u64,
pub store_config: PathBuf,
pub auth_path: PathBuf,
}Fields
rpc_endpoint: Endpointrpc_timeout_ms: u64store_config: PathBufauth_path: PathBufImplementations
Sourceimpl ClientConfig
impl ClientConfig
pub fn new(rpc_endpoint: Endpoint, rpc_timeout_ms: u64) -> Self
pub fn as_parts(&self) -> (Endpoint, u64, PathBuf, PathBuf)
pub fn with_rpc_endpoint(self, rpc_endpoint: Endpoint) -> Self
pub fn rpc_endpoint(&self) -> Endpoint
Sourcepub async fn into_client_builder(
self,
) -> Result<(ClientBuilder<FilesystemKeyStore>, FilesystemKeyStore)>
pub async fn into_client_builder( self, ) -> Result<(ClientBuilder<FilesystemKeyStore>, FilesystemKeyStore)>
Creates a TestClient builder and keystore.
Creates the client builder using the provided ClientConfig. The store uses a SQLite
database at a temporary location determined by the store config.
Sourcepub async fn into_client(self) -> Result<(TestClient, FilesystemKeyStore)>
pub async fn into_client(self) -> Result<(TestClient, FilesystemKeyStore)>
Creates a TestClient.
Creates the client using the provided ClientConfig. The store uses a SQLite database
at a temporary location determined by the store config. The client is synced to the
current state before being returned.